@@ -1,38 +1,38 @@
+from __future__ import annotations
+
+import logging
+from os.path import lexists
 from pathlib import Path
-from os.path import lexists
-import logging
-from typing import Union
 
-PathIsh = Union[str, Path]
 
 def atomic_append_raw(
-        path: PathIsh,
-        data: str,
-):
+    path: Path | str,
+    data: str,
+) -> None:
     path = Path(path)
     # https://stackoverflow.com/a/13232181
     enc = data.encode('utf8')
     # TODO handle windows properly? https://www.notthewizard.com/2014/06/17/are-files-appends-really-atomic/
     if len(enc) > 4096:
-        logging.warning("writing out %s might be non-atomic (see https://stackoverflow.com/a/1154599/706389)", data)
+        logging.warning("writing out %s might be non-atomic (see https://stackoverflow.com/a/1154599/706389)", data)  # noqa: LOG015
     with path.open('ab') as fo:
         fo.write(enc)
 
 
 # TODO might be useful in other projects?
-def assert_not_edited(path: Path):
+def assert_not_edited(path: Path) -> None:
     vim = '.' + path.name + '.swp'
     emacs = '.#' + path.name
     for x in [vim, emacs]:
         lf = path.parent / x
-        if lexists(lf): # lexist is necessary because emacs uses symlink for lock file
-            raise RuntimeError('File is being edited: {}'.format(lf))
+        if lexists(lf):  # lexist is necessary because emacs uses symlink for lock file
+            raise RuntimeError(f'File is being edited: {lf}')
 
 
 def atomic_append_check(
-        path: PathIsh,
-        data: str,
-):
+    path: Path | str,
+    data: str,
+) -> None:
     """
     This is editor (emacs/vim)-aware and checks for existence of swap file first.
     Not fully atomic, but hopefully atomic enough for all practical purposes
@@ -44,16 +44,21 @@ def atomic_append_check(
     atomic_append_raw(path, data)
 
 
-def test_atomic_append_check(tmp_path):
+def test_atomic_append_check(tmp_path: Path) -> None:
+    import platform
+
+    import pytest
+
+    if platform.system() == 'Windows':
+        pytest.skip("this test doesn't work on windows for now")
+
     of = tmp_path / 'test.org'
     of.touch()
 
-    import pytest # type: ignore
-
-    from subprocess import Popen, PIPE, check_call
+    from contextlib import contextmanager
+    from subprocess import PIPE, Popen
     from time import sleep
 
-    from contextlib import contextmanager
     @contextmanager
     def tmp_popen(*args, **kwargs):
         with Popen(*args, **kwargs) as p:
@@ -66,8 +71,8 @@ def test_atomic_append_check(tmp_path):
     atomic_append_check(of, 'data2')
     assert of.read_text() == 'data1data2'
 
-    with tmp_popen(['vi', '-c', 'startinsert', str(of)], stdin=PIPE, stdout=PIPE, stderr=PIPE) as p: # enter insert mode
-        for attempt in range(10):
+    with tmp_popen(['vi', '-c', 'startinsert', str(of)], stdin=PIPE, stdout=PIPE, stderr=PIPE):  # enter insert mode
+        for _attempt in range(10):
             # ugh, needs long pause for some reason
             sleep(1)
             swapfiles = list(tmp_path.glob('.*.swp'))
